@@ -116,3 +116,7 @@ $lang["COMPPATH"] = "השוואת נתיב:";
 $lang["WITHPATH"] = "עם נתיב:";
 $lang["FILEDELETED"] = "קובץ נמחק";
 $lang["FILEADDED"] = "קובץ חדש";
+
+$lang['SEARCH'] = "לחפש";
+$lang['SEARCH_PLACEHOLDER'] = "חפש פריטים כאן";
+$lang['NOITEMSFOUND'] = "לא נמצאו פריטים";
\ No newline at end of file
