@@ -117,3 +117,7 @@ $lang["COMPPATH"] = "比較元パス：";
 $lang["WITHPATH"] = "比較先パス：";
 $lang["FILEDELETED"] = "ファイル削除";
 $lang["FILEADDED"] = "新規ファイル";
+
+$lang['SEARCH'] = "探す";
+$lang['SEARCH_PLACEHOLDER'] = "こちらから商品を検索";
+$lang['NOITEMSFOUND'] = "項目は見つかりませんでした";
\ No newline at end of file
